@@ -2,9 +2,7 @@
 #ifndef CMainApp_included
 #define CMainApp_included
 
-#include <kmenubar.h>
-
-#include <map>
+#include <qmap.h>
 #include <iostream>
 #include <fstream>
 
@@ -13,33 +11,44 @@
 
 class CMainWindow;
 class KPopupMenu;
+class KAction;
+class KActionCollection;
+class KMenuBar;
 
-class CMainApp : public KMainWindow,virtual public CSendMessage
+class CMainApp : public KMainWindow,public CSendMessage
 {
     Q_OBJECT
 
 public:
     CMainApp ( const char* name = NULL,bool _first = false );
-    
+
     virtual ~CMainApp();
     virtual void append_message(const std::string&message);
-    
+
 protected:
     KPopupMenu*file;
+    KPopupMenu*quick_connects;
     KPopupMenu*db_menu;
     KPopupMenu*server_menu;
     KPopupMenu*setup_menu;
     KPopupMenu*dialogs_menu;
-    
+
     std::string logfile;
     std::ofstream filepointer;
     KMenuBar*MenuBar;
     CMainWindow* MainWidget;
-    std::map<std::string,int> id_map;
+    QMap<std::string,int> id_map;
+    QMap<int,QString> quick_map;
+    QMap<int,KAction*> action_list;
+    KActionCollection*server_actions;
 
     virtual void initToolbar();
     virtual void initMenu();
-    
+    virtual void initActions();
+    virtual void clearActions();
+
+    virtual void setActionsEnabled(KActionCollection*,bool);
+
 protected slots:
     void new_window();
     void raus_hier();
@@ -49,9 +58,12 @@ protected slots:
     bool queryExit();
     bool queryClose();
     void layout_setup();
+    void quick_selected(int);
 
 public slots:
     void windowClose();
+    void setup_quickies();
 signals:
+    void quickConnect(const QString&);
 };
 #endif // CMainApp_included
