@@ -1,28 +1,34 @@
 #include <kapp.h>
-#include "MainWindow.h"
-#include "Login.h"
-#include "createtable.h"
-#include "TextInput.h"
-#include "tableview.h"
-#include "StatusView.h"
-#include "my_sql.h"
-#include "ThreadView.h"
-#include "globals.h"
-#include "deltabledlg.h"
-#include <qmsgbox.h>
-#include "altertable.h"
-#include "changetablename.h"
-#include "stringres.h"
+#include <kconfig.h>
+#include <iostream>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include "sqlscript.h"
+#include <qmessagebox.h>
+#include <kglobal.h>
+#include <qtextview.h>
+#include <qwidgetstack.h>
+
+#include "MainWindow.h"
+#include "TextInput.h"
+#include "globals.h"
+#include "stringres.h"
+
+#include "kmysqladmin/frontend/deltabledlg.h"
+#include "kmysqladmin/frontend/mtable/createtable.h"
+#include "kmysqladmin/frontend/mtable/altertable.h"
+#include "kmysqladmin/frontend/changetablename.h"
+#include "kmysqladmin/sqlscript.h"
 #include "kmysqladmin/setup/settings.h"
 #include "kmysqladmin/helpers/qt_stl_string.h"
-#include "kglobal.h"
-#include "kconfig.h"
-#include "qtextview.h"
-#include "accessrights.h"
-#include <iostream>
+#include "kmysqladmin/frontend/login/Login.h"
+#include "kmysqladmin/frontend/browsetable/tableview.h"
+#include "kmysqladmin/frontend/browsetable/serverview.h"
+#include "kmysqladmin/frontend/status/StatusView.h"
+#include "kmysqladmin/frontend/status/ThreadView.h"
+#include "kmysqladmin/frontend/grantdialog/accessrights.h"
+#include "kmysqladmin/frontend/profiles/connection_profiles.h"
+#include "kmysqladmin/setup/settings_defines.h"
+#include "kmysqladmin/backend/my_sql/my_sql.h"
 
 using namespace std;
 
@@ -32,36 +38,38 @@ CMainWindow::CMainWindow( QWidget* parent, const char* name )
     :Inherited( parent, name )
 {
     TableView = 0;
+    OldTableView = 0;
     StatusView = 0;
     ThreadView = 0;
     sql_server = 0;
     Grants = 0;
     sql_script = 0;
+    m_Profiles = 0;
     msg_ptr = 0;
+    m_CurrentCompact = GlobalSettings.getCompactLayout();
+    m_CurrentOldbrowser=GlobalSettings.getOldBrowser();
+    connect(&GlobalSettings,SIGNAL(settingsChanged()),this,SLOT(config_changed()));
 }
 
 CMainWindow::~CMainWindow()
 {
     if (sql_server && sql_server->success_connect()) {
-    GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
-                     sql_server->Port(),sql_server->Pass());
+        GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
+            sql_server->Port(),sql_server->Pass());
     }
 }
 
 void CMainWindow::connectSql()
 {
     CLogin login;
-    QString host;
-    QString User;
-    QString pass;
-    QString port;
     if (login.exec()) {
-        host = login.get_host();
-        User = login.get_user();
-        pass = login.get_pass();
-        port = login.get_port();
         _connect(login.get_user(),login.get_host(),
         login.get_port(),login.get_pass());
+        KConfig * k = KGlobal::config();
+        k->setGroup("last_login");
+        k->writeEntry("user",login.get_user());
+        k->writeEntry("host",login.get_host());
+        k->writeEntry("port",login.get_port());
     }
 }
 
@@ -74,7 +82,7 @@ void CMainWindow::disconnectSql()
 {
     if (!sql_server)
         return;
-    if (sql_server && sql_server->success_connect()) {
+    if (sql_server->success_connect()) {
         GlobalSettings.SaveLastLogin(sql_server->User(),sql_server->Host(),
                                      sql_server->Port(),sql_server->Pass());
     }
@@ -84,13 +92,33 @@ void CMainWindow::disconnectSql()
     emit disconnected();
 }
 
+template<class T> void CMainWindow::initBrowser(T**target,const char*name)
+{
+    if (!sql_server || !sql_server->success_connect())
+        return;
+    if (!(*target)) {
+        *target = new T(sql_server,0,name);
+        if (m_CurrentCompact) {
+            (*target)->setMinimumSize(0,0);
+            m_MainStack->addWidget(*target);
+        }
+    }
+    if (! (*target)->isVisible()) {
+        if (!m_CurrentCompact) {
+            (*target)->show();
+        } else {
+            m_MainStack->raiseWidget((*target));
+            (*target)->standalone(false);
+        }
+    }
+}
+
 void CMainWindow::browseTables()
 {
-    if (!TableView) {
-        TableView = new CTableView(sql_server,0,"TableView");
-    }
-    if (!TableView->isVisible()) {
-        TableView->show();
+    if (m_CurrentOldbrowser) {
+        initBrowser<CTableView>(&OldTableView,"TableView");
+    } else {
+        initBrowser<ServerView>(&TableView,"TableView");
     }
 }
 
@@ -134,20 +162,12 @@ void CMainWindow::createDB()
 
 void CMainWindow::dispStatus()
 {
-    if (!StatusView)
-        StatusView = new CStatusView(sql_server,0,"StatusView");
-    if (!StatusView->isVisible())
-        StatusView->show();
+    initBrowser<CStatusView>(&StatusView,"StatusView");
 }
 
 void CMainWindow::view_threads()
 {
-    if (!sql_server || !sql_server->success_connect())
-        return;
-    if (!ThreadView)
-        ThreadView = new CThreadView(sql_server,0,"ThreadView");
-    if (!ThreadView->isVisible())
-        ThreadView->show();
+    initBrowser<CThreadView>(&ThreadView,"ThreadView");
 }
 
 void CMainWindow::clearOutput()
@@ -157,10 +177,7 @@ void CMainWindow::clearOutput()
 
 void CMainWindow::accessControl()
 {
-    if (!Grants)
-        Grants = new CAccessrights(sql_server);
-    if (!Grants->isVisible())
-        Grants->show();
+    initBrowser<CAccessrights>(&Grants,"AccessControl");
 }
 
 void CMainWindow::reload_grants()
@@ -192,7 +209,7 @@ void CMainWindow::shutdown()
     int i;
     i = KMessageBox::questionYesNo(this,CStringRes::get_string(56),
                                    CStringRes::get_string(130));
-    if (i != KMessageBox::Yes) 
+    if (i != KMessageBox::Yes)
         return;
     if (sql_server) {
         i = sql_server->shutdown();
@@ -237,7 +254,7 @@ void CMainWindow::sql_Edit()
     if (!sql_script) {
         sql_script = new CSqlScript(sql_server,0,"SQL_Editor");
     }
-    if (!sql_script->isVisible()) 
+    if (!sql_script->isVisible())
         sql_script->show();
 }
 
@@ -247,30 +264,55 @@ bool CMainWindow::close()
     return CMainWindowData::close();
 }
 
+template<class T> void CMainWindow::removeWindow(T**ptr)
+{
+    if ((*ptr)) {
+        if ((*ptr)->parentWidget()==m_MainStack) {
+            m_MainStack->removeWidget((*ptr));
+        }
+        (*ptr)->close(true);
+        (*ptr) = 0;
+    }
+}
+
 void CMainWindow::CloseAllDialogs()
 {
-    if (TableView) {
-        TableView->close(true);
-        TableView = 0;
+    if (m_CurrentCompact) {
+        showLog();
     }
-    if (StatusView) {
-        StatusView->close(true);
-        StatusView = 0;
-    }
-    if (ThreadView) {
-        ThreadView->close(true);
-        ThreadView = 0;
-    }
-    if (Grants) {
-        Grants->close(true);
-        Grants = 0;
-    }
-    if (sql_script) {
-        sql_script->close(true);
-        sql_script = 0;
+    removeWindow<ServerView>(&TableView);
+    removeWindow<CTableView>(&OldTableView);
+    removeWindow<CStatusView>(&StatusView);
+    removeWindow<CThreadView>(&ThreadView);
+    removeWindow<CAccessrights>(&Grants);
+    removeWindow<CSqlScript>(&sql_script);
+}
+
+template<class T> void CMainWindow::reparentWindow(T**ptr)
+{
+    if ((*ptr)) {
+        if (m_CurrentCompact&&(*ptr)->parentWidget()!=m_MainStack) {
+            m_MainStack->addWidget((*ptr));
+        } else if (!m_CurrentCompact&&(*ptr)->parentWidget()==m_MainStack) {
+            (*ptr)->reparent(0,QPoint(10,10),true);
+        }
+        (*ptr)->standalone(!m_CurrentCompact);
     }
 }
 
+void CMainWindow::reparent_subwindows()
+{
+    bool c = GlobalSettings.getCompactLayout();
+    if (c == m_CurrentCompact) return;
+    m_CurrentCompact = c;
+    reparentWindow<ServerView>(&TableView);
+    reparentWindow<CTableView>(&OldTableView);
+    reparentWindow<CStatusView>(&StatusView);
+    reparentWindow<CThreadView>(&ThreadView);
+    reparentWindow<CAccessrights>(&Grants);
+    showLog();
+}
+
 void CMainWindow::RestoreLastConnect()
 {
     string user,host,port,pass;
@@ -278,6 +320,19 @@ void CMainWindow::RestoreLastConnect()
     _connect(user,host,port,pass);
 }
 
+void CMainWindow::ConnectQuick(const QString&which)
+{
+    if (which.length()==0) return;
+
+    QMap<QString,QString> qvals = GlobalSettings.getConnectProfile(which);
+    if (qvals.size()==0) return;
+
+    _connect(QT_TO_STL_STRING(qvals[Settings_defines::_PROFILES_user]),
+        QT_TO_STL_STRING(qvals[Settings_defines::_PROFILES_host]),
+        QT_TO_STL_STRING(qvals[Settings_defines::_PROFILES_port]),
+        QT_TO_STL_STRING(qvals[Settings_defines::_PROFILES_pass]));
+}
+
 void CMainWindow::_connect(const std::string&user,const std::string&host,
                const std::string&port,const std::string&pass)
 {
@@ -286,28 +341,17 @@ void CMainWindow::_connect(const std::string&user,const std::string&host,
     if (!sql_server)
         return;
     sql_server->set_message_call_back(msg_ptr);
-    if (StatusView) {
-        delete StatusView;StatusView = 0L;
-    }
-    if (TableView) {
-        delete TableView;TableView = 0L;
-    }
-    if (ThreadView) {
-        delete ThreadView;ThreadView = 0L;
-    }
-    if (Grants) {
-        delete Grants;Grants = 0;
-    }
-    if (sql_script) {
-        delete sql_script;sql_script=0;
-    }
-    KConfig * k = KGlobal::config();
-    k->setGroup("last_login");
-    k->writeEntry("user",STL_TO_QT_STRING(user));
-    k->writeEntry("host",STL_TO_QT_STRING(host));
-    k->writeEntry("port",STL_TO_QT_STRING(port));
+
+    removeWindow<ServerView>(&TableView);
+    removeWindow<CTableView>(&OldTableView);
+    removeWindow<CStatusView>(&StatusView);
+    removeWindow<CThreadView>(&ThreadView);
+    removeWindow<CAccessrights>(&Grants);
+    removeWindow<CSqlScript>(&sql_script);
+
     sql_server->sql_connect(host,user,pass,port);
     if (sql_server->success_connect()) {
+        GlobalSettings.SaveLastLogin(user,host,port,pass);
         string head=user;
         head+="@";
         if (host.size()==0) {
@@ -327,3 +371,30 @@ void CMainWindow::_connect(const std::string&user,const std::string&host,
         emit disconnected();
     }
 }
+
+void CMainWindow::showLog()
+{
+    m_MainStack->raiseWidget(OutputArea);
+}
+
+/*!
+    \fn CMainWindow::connection_profiles
+ */
+void CMainWindow::connection_profiles()
+{
+    ConnectionProfiles dlg;
+    dlg.exec();
+    emit quickConsChanged();
+}
+
+void CMainWindow::config_changed()
+{
+    reparent_subwindows();
+    bool c = GlobalSettings.getOldBrowser();
+    if (c != m_CurrentOldbrowser) {
+        showLog();
+        removeWindow<ServerView>(&TableView);
+        removeWindow<CTableView>(&OldTableView);
+    }
+    m_CurrentOldbrowser=c;
+}
