@@ -1,6 +1,6 @@
 #include "PatternPair.h"
 
-CPatternPair::CPatternPair(const char*Entry,const char*Pattern,const char*aOp,bool ano_escape)
+CPatternPair::CPatternPair(const char*Entry,const char*Pattern,const char*aOp,bool ano_escape,bool ais_name)
 {
     entry=Entry?Entry:"";
     pattern=Pattern?Pattern:"";
@@ -9,9 +9,10 @@ CPatternPair::CPatternPair(const char*Entry,const char*Pattern,const char*aOp,bo
     large_text = false;
     op = aOp;
     no_escape = ano_escape;
+    pattern_is_name=ais_name;
 }
 
-CPatternPair::CPatternPair(const std::string&Entry,const std::string&Pattern,const std::string&aOp,bool ano_escape)
+CPatternPair::CPatternPair(const std::string&Entry,const std::string&Pattern,const std::string&aOp,bool ano_escape,bool ais_name)
 {
     entry=Entry;
     pattern=Pattern;
@@ -20,6 +21,7 @@ CPatternPair::CPatternPair(const std::string&Entry,const std::string&Pattern,con
     large_text = false;
     op = aOp;
     no_escape = ano_escape;
+    pattern_is_name=ais_name;
 }
 
 CPatternPair::CPatternPair(const CPatternPair& old)
@@ -36,10 +38,12 @@ CPatternPair&CPatternPair::operator=(const CPatternPair&old)
 void CPatternPair::copy_old(const CPatternPair& old)
 {
     entry=old.get_entry();
-    pattern=old.get_pattern();
+    pattern=old.std_pattern();
     setIsNumeric(old.isNumeric());
     setIsPassword(old.isPassword());
     setLargeText(old.isLargeText());
+    setBlob(old.isBlob());
     no_escape=old.get_no_escape();
     op=old.get_op();
+    pattern_is_name=old.get_is_name();
 }
