@@ -3,8 +3,8 @@
 
 #include <qdialog.h>
 #include <qlabel.h>
-#include <qpushbt.h>
-#include <qlined.h>
+#include <qpushbutton.h>
+#include <qlineedit.h>
 
 class CTextInputData : public QDialog
 {
