@@ -6,10 +6,6 @@
 #include <string>
 #include <vector>
 
-#ifndef _WIN32
-class QFont;
-#endif
-
 //for duplicate files
 int copy_file(const char*source, const char*target,bool lock_it = false);
 int move_file(const char*source, const char*target,bool lock_it = false);
