@@ -2,14 +2,11 @@
 #ifndef _smart_pointer_h
 #define _smart_pointer_h
 
-#if defined WIN32
-#include <windows.h>
-#elif defined  _USE_PTHREAD
-#include "cmutex.h"
+#if defined  QT_THREAD_SUPPORT
+#include "qmutex.h"
 #endif
 
 #include <string>
-#include "kmysqladmin/helpers/nullpointer_exception.h"
 /*!
  * \file smart_pointer.h
  * \brief smart pointer and reference counter
@@ -22,39 +19,32 @@ class ref_count {
 protected:
     //! reference count member
     long m_RefCount;
-#ifdef _USE_PTHREAD
-    CMutex m_RefcountMutex;
+#ifdef QT_THREAD_SUPPORT
+    QMutex m_RefcountMutex;
 #endif
 public:
     //! first reference must be added after "new" via Pointer()
     ref_count() : m_RefCount(0)
-#ifdef _USE_PTHREAD
+#ifdef QT_THREAD_SUPPORT
                   ,m_RefcountMutex()
 #endif
     {}
     virtual ~ref_count() {}
     //! add a reference
-#ifdef WIN32
-    void Incr() {InterlockedIncrement(& m_RefCount); }
-#else
     void Incr() {
-#ifdef _USE_PTHREAD
-        CAutoMutex a(&m_RefcountMutex);
+#ifdef QT_THREAD_SUPPORT
+        QMutexLocker a(&m_RefcountMutex);
 #endif
         ++m_RefCount;
     }
-#endif
     //! delete a reference
-#ifdef WIN32
-    void Decr() { InterlockedDecrement(& m_RefCount); }
-#else
-    void Decr() {
-#ifdef _USE_PTHREAD
-        CAutoMutex a(&m_RefcountMutex);
+    bool Decr() {
+#ifdef QT_THREAD_SUPPORT
+        QMutexLocker a(&m_RefcountMutex);
 #endif
         --m_RefCount;
+        return Shared();
     }
-#endif
     //! is it referenced
     bool Shared() { return (m_RefCount > 0); }
 };
@@ -63,7 +53,7 @@ public:
 template<class T> class smart_pointer {
     //! pointer to object
     /*!
-     * this object must contain Incr(), Decr() and Shared() 
+     * this object must contain Incr(), Decr() and Shared()
      * methode as public members. The best way is, that it will be a child
      * class of RefCount
      */
@@ -78,51 +68,52 @@ public:
      */
     ~smart_pointer()
     {
-        if (ptr){
-            ptr->Decr();
-            if (!ptr->Shared())
-                delete ptr;
+        if (ptr && !ptr->Decr()) {
+            delete ptr;
         }
     }
     //! construction
-    smart_pointer(T* t) { if (ptr = t) ptr->Incr(); }
+    smart_pointer(T* t) { if ( (ptr = t) ) ptr->Incr(); }
     //! Pointer copy
-    smart_pointer(const smart_pointer<T>& p) 
-    { if (ptr = p.ptr) ptr->Incr(); }
+    smart_pointer(const smart_pointer<T>& p)
+    { if ( (ptr = p.ptr) ) ptr->Incr(); }
     //! pointer copy by assignment
-    smart_pointer<T>& operator= (const smart_pointer<T>& p) 
+    smart_pointer<T>& operator= (const smart_pointer<T>& p)
     {
         // already same: nothing to do
         if (ptr == p.ptr) return *this;
         // decouple reference
-        if (ptr) { ptr->Decr(); if (!ptr->Shared()) delete ptr; } 
+        if ( ptr && !ptr->Decr()) delete ptr;
         // establish new reference
-        if (ptr = p.ptr) ptr->Incr();
+        if ( (ptr = p.ptr) ) ptr->Incr();
         return *this;
     }
     smart_pointer<T>& operator= (T*p)
     {
         if (ptr==p)return *this;
-        if (ptr) {
-            ptr->Decr();
-            if (!ptr->Shared()) delete ptr;
-        }
-        if (ptr=p) ptr->Incr();
+        if (ptr && !ptr->Decr()) delete ptr;
+        if ( (ptr=p) ) ptr->Incr();
         return *this;
     }
 
     //! cast to conventional pointer
-    operator T* () { return ptr; }
+    operator T* () const { return ptr; }
+
     //! deref: fails for NULL pointer
-    T& operator* () { if (ptr == NULL) throw nullpointer_exception("Bad smartpointer operator *"); return *ptr; }
+    T& operator* () {return *ptr; }
+    //! deref: fails for NULL pointer
+    const T& operator* ()const {return *ptr; }
+
     //! deref with method call
-    T* operator-> () { if (ptr == NULL) throw nullpointer_exception("Bad smartpointer operator ->"); return ptr; }
+    T* operator-> () {return ptr; }
     //! deref with const method call
-    T* operator-> ()const { if (ptr == NULL) throw nullpointer_exception("Bad smartpointer operator ->"); return ptr; }
+    const T* operator-> ()const {return ptr; }
+
     //! supports "if (pointer)"
     operator bool () const { return (ptr != NULL); }
-    //! same as non const
+    //! "if (pointer)" as non const
     operator bool () { return ptr != NULL;}
+
     //! support if (!pointer)"
     bool operator! () const { return (ptr == NULL); }
     //! support if (!pointer)" as non const
