@@ -6,10 +6,6 @@
 
 #include <qstring.h>
 
-#ifndef rcsid
-static const char rcsid[]="$Id: stringhelper.cpp,v 1.6 2003/11/04 12:51:47 ral Exp $";
-#endif
-
 std::string FormatSTLString(const char*Format,...)
 {
     std::string msg = "";
@@ -19,9 +15,9 @@ std::string FormatSTLString(const char*Format,...)
     va_list ap;
     va_start(ap,Format);
     int size = 100;
-    
+
     buffer = new char[size];
-    
+
     while (1) {
 #ifndef _WIN32
         chars = vsnprintf(buffer,size,Format,ap);
@@ -60,3 +56,21 @@ bool Casecmp::operator()(const std::string&x, const std::string&y)const
     if (p==x.end()) return q!=y.end();
     return toupper(*p)<toupper(*q);
 }
+
+char Bin2Hex::hexconvtab[] = "0123456789abcdef";
+
+Bin2Hex::Bin2Hex(const std::string&x)
+    :arg(x),result(arg.size()*2+1,char(0))
+{
+    size_t i,j;
+    for (i = j = 0; i < arg.size();++i) {
+        result[j++]=hexconvtab[((unsigned char)arg.at(i)) >> 4];
+        result[j++]=hexconvtab[((unsigned char)arg.at(i)) & 15];
+    }
+    result[j]=0;
+}
+
+const std::string&Bin2Hex::operator()()const
+{
+    return result;
+}
