@@ -53,7 +53,7 @@
 #define ID_EDIT_PASTE               11030
 
 ///////////////////////////////////////////////////////////////////
-// View-menu entries                    
+// View-menu entries
 #define ID_VIEW_TOOLBAR             12010
 #define ID_VIEW_STATUSBAR           12020
 
@@ -92,5 +92,9 @@
 #define ID_NEW_TABLE               13018
 #define ID_MODIFY_TABLE            13019
 #define ID_SEARCH_TABLE            13020
+#define ID_SHOW_LOG                13021
+
+#define ID_CONFIGURE               13022
+#define ID_PROFILES                13023
 
 #endif // RESOURCE_H
