@@ -21,8 +21,8 @@ protected slots:
     virtual void selected_Font(const QFont&);
 
 signals:
-    void snonpropFont(QFont&);
-    void sfixFont(QFont&);
+    void snonpropFont(const QFont&);
+    void sfixFont(const QFont&);
 
 protected:
     QFont fixFont;
