@@ -1,21 +1,26 @@
 // -*- Mode: C++; -*-
 
-#include "kmysqladmin/profile.h"
-#include <string>
 
 #ifndef _settings_h
 #define _settings_h
+#include <string>
 
 #include "settingsignals.h"
+
+namespace KWallet {
+  class Wallet;
+}
+
 class QFont;
 class QColor;
 
 class CSettings:public Settingsignals
 {
 protected:
-    eProfile LastInit;
     bool init_files();
 
+    static KWallet::Wallet*openWallet(const std::string&aDir);
+
 public:
     CSettings();
     ~CSettings();
@@ -31,7 +36,7 @@ public:
 
     int ThreadPolltime()const;
     void ThreadPolltime(int aTimeout);
-    
+
     int StatusPolltime()const;
     void StatusPolltime(int aTimeout);
 
@@ -39,13 +44,31 @@ public:
     void ScriptOutputAsRich(bool);
     bool SyntaxHighlight()const;
     void SyntaxHighlight(bool);
-    
+
     QColor getScriptColor(const std::string&which,const QColor&aDefaultColor);
     void   setScriptColor(const std::string&which,const QColor&aColor);
     bool   getScriptbold(const std::string&which,bool def);
     void   setScriptbold(const std::string&which,bool how);
     bool   getScriptit(const std::string&which,bool def);
     void   setScriptit(const std::string&which,bool how);
+
+    void getBlobimages(bool&aDisplayimages, bool&aScaleimages, int&aMaxwidth, int&aMaxheight);
+    void setBlobimages(bool aDisplayimages, bool aScaleimages, int aMaxwidth, int aMaxheight);
+
+    QMap<QString,QString> getConnectProfile(const QString&aProfile);
+    QStringList getConnectProfilesList();
+    void addConnectProfile(const QString&aName,const QString&aHost,const QString&aUser,const QString&aPort,const QString&aPass);
+    void addConnectProfile(const QMap<QString,QString>&aConnection);
+    void deleteConnectProfile(const QString&aName);
+
+    void setRealmultiLines(bool);
+    bool getRealmultilines()const;
+
+    void setCompactLayout(bool);
+    bool getCompactLayout()const;
+
+    void setOldBrowser(bool how);
+    bool getOldBrowser()const;
 };
 
 extern CSettings GlobalSettings;
