@@ -1,10 +1,10 @@
 //-*-Mode: C++;-*-
 /***************************************************************************
-                          settingsignals.h  -  description                              
-                             -------------------                                         
-    begin                : Sun Oct 1 2000                                           
-    copyright            : (C) 2000 by Rajko Albrecht                         
-    email                : Rajko.Albrecht@informatik.tu-chemnitz.de                                     
+                          settingsignals.h  -  description
+                             -------------------
+    begin                : Sun Oct 1 2000
+    copyright            : (C) 2000 by Rajko Albrecht
+    email                : Rajko.Albrecht@informatik.tu-chemnitz.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -12,7 +12,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 #ifndef SETTINGSIGNALS_H
@@ -23,17 +23,20 @@
 /**
   *@author Rajko Albrecht
   */
-class Settingsignals:public QObject 
+class Settingsignals:public QObject
 {
     Q_OBJECT
-public: 
+public:
     Settingsignals(){}
     virtual ~Settingsignals(){}
+    void make_settings_changed_signal(){emit settingsChanged();}
+
 signals:
     void npropfont_changed();
     void fixfont_changed();
     void threadtimer_changed(int);
     void statustimer_changed(int);
+    void settingsChanged();
 
 protected:
     void make_f_font_signal(){emit fixfont_changed();}
