@@ -1,7 +1,7 @@
-#include <qmenudta.h>
+#include <qmenudata.h>
 #include <kpopupmenu.h>
 #include <qfile.h>
-#include <qfileinf.h>
+#include <qfileinfo.h>
 #include <qtextstream.h>
 #include <qlayout.h>
 #include <qmultilineedit.h>
@@ -30,15 +30,16 @@
 #endif
 
 #include "sqlscript.h"
-#include "my_sql.h"
+#include "kmysqladmin/backend/my_sql/my_sql.h"
 #include "kmysqladmin/helpers/stringlist.h"
 #include "kmysqladmin/helpers/qt_stl_string.h"
-#include "stringres.h"
-#include "scriptsplit.h"
-#include "TextInput.h"
-#include "sqlsyntax.h"
+#include "kmysqladmin/stringres.h"
+#include "kmysqladmin/frontend/scripteditor/scriptsplit.h"
+#include "kmysqladmin/TextInput.h"
+#include "kmysqladmin/frontend/scripteditor/sqlsyntax.h"
 #include "kmysqladmin/setup/settings.h"
 #include "kmysqladmin/setup/setupscriptcolor.h"
+#include "kmysqladmin/frontend/mysqlhelp/mysqlhelp.h"
 
 #define Inherited CSqlScriptData
 
@@ -149,15 +150,16 @@ CSqlScript::CSqlScript(smart_pointer<CMySql>& _sql_server,QWidget* parent,const
     scriptEdit->setTextFormat(Qt::PlainText);
 
     setupSyntaxObject();
-    
-    if (sql_server) {
-        sql_server->set_message_call_back(this);
-    }
     StatusText->setText(GET_TEXT(136));
     connect(&GlobalSettings,SIGNAL(fixfont_changed()),this,SLOT(FixFontChanged()));
     connect(resultEdit,SIGNAL(cursormove()),SLOT(set_cursor_info()));
     connect(errorEdit,SIGNAL(cursormove()),SLOT(set_cursor_info()));
     connect(scriptEdit,SIGNAL(cursormove()),SLOT(set_cursor_info()));
+    if (sql_server->master_version()>3) {
+        /* use the master handle */
+        QWidget*twidget = new CMysqlhelp(_sql_server,TabBar,"Mysql help");
+        TabBar->insertTab( twidget, QString("Mysql help") );
+    }
     FixFontChanged();
     TabSelected(0);
 }
@@ -217,7 +219,7 @@ void CSqlScript::submit()
     ResultText = "";
     ErrorText = "";
     TabBar->setCurrentPage(1);
-    stringlist target,sizes,headers;
+    stringlist target,headers;
     stringlist commands;
     list_vector target2;
 
@@ -236,12 +238,11 @@ void CSqlScript::submit()
     resultEdit->setText("");
     for (unsigned int i = 0; i < commands.size();++i) {
         target.resize(0);
-        sizes.resize(0);
         headers.resize(0);
         int update_counter = 0;
         KApplication::kApplication()->processEvents(100);
         if (!rich_text_set) {
-            if (!sql_server->do_statement(commands[i],target,sizes,headers,true)) {
+            if (!sql_server->do_statement(commands[i],target,headers,true)) {
                 had_errors = true;
                 break;
             }
