@@ -6,14 +6,14 @@
 #include <kmenubar.h>
 #include <kurl.h>
 #include <kaction.h>
-#include "sqlscriptdata.h"
+#include "kmysqladmin/frontend/scripteditor/sqlscriptdata.h"
 #include <string>
 #include "kmysqladmin/helpers/stringlist.h"
-#include "sendmessage.h"
+#include "kmysqladmin/sendmessage.h"
 #include "kstatusbar.h"
 #include <qtimer.h>
 #include "kmysqladmin/helpers/smart_pointer.h"
-#include "edit.h"
+#include "kmysqladmin/frontend/scripteditor/edit.h"
 
 class CMySql;
 class KPopupMenu;
