@@ -171,7 +171,9 @@ const string_res CStringRes::res_array[]=
     string_res(159,i18n("Show result as Richtext")),
     string_res(160,i18n("D&ialogs")),
     string_res(161,i18n("S&erver")),
-    string_res(162,i18n("Use highlighting for sql script"))
+    string_res(162,i18n("Use highlighting for sql script")),
+    string_res(163,i18n("Connection profiles")),
+    string_res(164,i18n("Show logwindow"))
 };
 
 #undef i18n
@@ -184,7 +186,7 @@ const char* CStringRes::get_string(unsigned int id)
 {
     unsigned int size = sizeof(res_array)/sizeof(string_res);
     for (unsigned int count = 0;count < size;++count) {
-	if(res_array[count].first == id) {
+    if(res_array[count].first == id) {
 #ifndef _WIN32
             return res_array[count].second.c_str();
 #else
