@@ -13,7 +13,7 @@ protected:
     static const string_res res_array[];
     std::string last_message;
 public:
-    CStringRes(){last_message = "";}
+    CStringRes():last_message(""){}
     ~CStringRes(){}
     static const char*get_string(unsigned int id);
 };
