@@ -3,10 +3,10 @@
 #endif
 
 #include "tabledescr.h"
-#include "pairs.h"
+#include "kmysqladmin/helpers/pairs.h"
 #include <algorithm>
 
-CKeyDescriptor::CKeyDescriptor(const CKeyDescriptor&old) 
+CKeyDescriptor::CKeyDescriptor(const CKeyDescriptor&old)
 {
     name = old.name;
     ColumnsList = old.ColumnsList;
@@ -81,11 +81,11 @@ CColumnDescriptor::CColumnDescriptor()
     name = "";
     Def = "";
     table = "";
-    
+
     FieldType = 0;
     MaxLength = 0;
     MaxDecimals = 0;
-    
+
     AutoIncrement = false;
     PrimaryField = false;
     Binary = false;
@@ -97,6 +97,7 @@ CColumnDescriptor::CColumnDescriptor()
     Numeric = false;
     UniqueValue = false;
     Set = false;
+    Text = false;
 }
 
 void CColumnDescriptor::copy_old(const CColumnDescriptor*old)
@@ -104,11 +105,11 @@ void CColumnDescriptor::copy_old(const CColumnDescriptor*old)
     name = old->name;
     Def = old->Def;
     table = old->table;
-    
+
     FieldType = old->FieldType;
     MaxLength = old->MaxLength;
     MaxDecimals = old->MaxDecimals;
-    
+
     AutoIncrement = old->AutoIncrement;
     PrimaryField = old->PrimaryField;
     Binary = old->Binary;
@@ -122,6 +123,7 @@ void CColumnDescriptor::copy_old(const CColumnDescriptor*old)
     Enums = old->Enums;
     Unsigned = old->Unsigned;
     Set = old->Set;
+    Text = old->Text;
 }
 
 CColumnDescriptor::CColumnDescriptor(const CColumnDescriptor&old)
